import Taro, { Component } from '@tarojs/taro'
import { View, Button, Text, Swiper, SwiperItem, Image } from '@tarojs/components'
import { AtSearchBar, AtSegmentedControl, AtTabBar, AtDrawer  } from 'taro-ui'
import URL from '../../serviceAPI.config'

import './shop.scss'
import ShopItem from '../../component/shopItemComponent/shopItemComponent'
import SideBarFilter from '../../component/sideBarFilterComponent/sideBarFilterComponent'
class Shop extends Component {
    // 项目配置
    config = {
        navigationBarTitleText: '店铺'
    }
    constructor() {
        super(...arguments)
        this.state = {
            shopItem:'',
            value: '',
            shopId:'',
            shopName:'',
            filterBar: ['综合排序','销量','新品','价格','人气','筛选'],
            FilterText:'',
            selectedFilterValue:0,
            isShow:true
        }
    }
    onChange(value) {
        this.setState({
            value: value
        })
    }
 
    onActionClick() {
        console.log('开始搜索')
    }
    getSearchParams(){
        Taro.request({
            url: URL.FilterText,
            method: 'POST',
            dataType: 'json',
            data: {
                goods: JSON.stringify({
                     shop_name: false, 
                     shop_id: 808, 
                     shop_class_id: "" }),
               
                goodsSpec: JSON.stringify([]),
                goodsParam: JSON.stringify([]),
                goodsParamExt: JSON.stringify([]),

            },
            header: {
                'content-type': 'application/x-www-form-urlencoded',
                'X-Requested-With': 'XMLHttpRequest'
            }
        })
            .then(res => {
                this.setState({ FilterText: res.data })
            })
    }
   

    getShopInfo() {
        Taro.request({
            url: URL.GoodsSearch,
            method:'POST',
            dataType: 'json',
            data:{
                goods: JSON.stringify({ 
                    curr_page: 1,
                     page_count: 50,
                     shop_name: false,
                    shop_id: 1305,
                     config_id: 4,
                     shop_class_id: ''
                    
            }),
                goodsRegion: JSON.stringify({}),
                goodsSpec: JSON.stringify([]),
                goodsParam: JSON.stringify([]),
                goodsParamExt: JSON.stringify([]),

            },
            header: {
                'content-type': 'application/x-www-form-urlencoded',
                'X-Requested-With':'XMLHttpRequest'
            }
        })
            .then(res => {
               // console.log(res)
                this.setState({ shopItem:res.data})
            })
    }
    onClickFilter(value){
        this.setState({selectedFilterValue:value})
        const sideFilter=5
        if (value === sideFilter){
            this.setState({ isShow:true})
        }
    }
    isShowFilter(){
        this.setState({ isShow: false })
    }
   
    componentWillMount() {
        this.setState({ shopId: this.$router.params.id, shopName: this.$router.params.name}) // 输出 { id: 2, type: 'test' }
    }
    componentDidMount(){
        this.getShopInfo()
        this.getSearchParams()
    }

    componentDidShow() { }

    componentDidHide() { }

    render() {
        
        const shopName= this.state.shopName
        const ShopItemElementsArray =this.state.shopItem? this.state.shopItem.goods.map((item,index)=>{
            return <View key={index} className='shop-item' >
                <ShopItem item={item}></ShopItem>
            </View> 
        }):null
         
        const filterElementsArray=this.state.filterBar.map((item,index)=>{
            return <View className={index === this.state.selectedFilterValue ? 'filter-title actived' :'filter-title'} key={index} onClick={this.onClickFilter.bind(this,index)}>
                <Text className='text'>
                    {item}
                        </Text>
                <Text className='icon'>

                </Text>

            </View>
        })


        return (
           <View className='shop'>
             <View className='searchBar-box'>
                    <AtSearchBar className='search-button'
                  showActionButton
                  value={this.state.value}
                  onChange={this.onChange.bind(this)}
                  onActionClick={this.onActionClick.bind(this)}
                />
             </View>
             <View className='banner-box'>
                    <Image src={URL.Base + 'Public/visual_editing/img/ksh_bg.jpg'} style='height:120px' />
                    <View className='shop-name'>{shopName}</View>
             </View>
            <View className='nav-box'>
                <View className='nav'>
                        <View className='shop-cate'>
                            <Text className='text'>
                                店铺全部分类
                            </Text>

                        </View>
                        <View className='home-link'>
                            <Text className='text'>
                                首页
                            </Text>
                        </View>
                        <View className='home-link'>
                            <Text className='text'>
                                店铺说明
                            </Text>
                        </View>
                </View>
             </View>
            <View className='filter-box'>
                    {filterElementsArray}
            </View>
            <View className={this.state.isShow ? 'side-filter show' :'side-filter'}>
                    <View className='left' onClick={this.isShowFilter.bind(this)}></View>
                <View className='right'>
                        <SideBarFilter FilterText={this.state.FilterText}></SideBarFilter>
                </View>
                
            </View>
            <View className='container'>
                    {ShopItemElementsArray}
                    
            </View>
           </View> 
        )
    }
}

export default Shop
